@@ -144,9 +144,13 @@ enum [[deprecated]] : int {
     SBK_QWAVEDECODER_IDX                                     = 168,
     SBK_QWINDOWCAPTURE_ERROR_IDX                             = 172,
     SBK_QWINDOWCAPTURE_IDX                                   = 170,
-    SBK_QTVIDEO_ROTATION_IDX                                 = 176,
-    SBK_QTMULTIMEDIAQTVIDEO_IDX                              = 174,
-    SBK_QTMULTIMEDIA_IDX_COUNT                               = 178,
+    SBK_QTAUDIO_ERROR_IDX                                    = 176,
+    SBK_QTAUDIO_STATE_IDX                                    = 178,
+    SBK_QTAUDIO_VOLUMESCALE_IDX                              = 180,
+    SBK_QTMULTIMEDIAQTAUDIO_IDX                              = 174,
+    SBK_QTVIDEO_ROTATION_IDX                                 = 184,
+    SBK_QTMULTIMEDIAQTVIDEO_IDX                              = 182,
+    SBK_QTMULTIMEDIA_IDX_COUNT                               = 186,
 };
 
 // Type indices
@@ -238,9 +242,13 @@ enum : int {
     SBK_QWaveDecoder_IDX                                     = 84,
     SBK_QWindowCapture_Error_IDX                             = 86,
     SBK_QWindowCapture_IDX                                   = 85,
-    SBK_QtVideo_Rotation_IDX                                 = 88,
-    SBK_QtMultimediaQtVideo_IDX                              = 87,
-    SBK_QtMultimedia_IDX_COUNT                               = 89,
+    SBK_QtAudio_Error_IDX                                    = 88,
+    SBK_QtAudio_State_IDX                                    = 89,
+    SBK_QtAudio_VolumeScale_IDX                              = 90,
+    SBK_QtMultimediaQtAudio_IDX                              = 87,
+    SBK_QtVideo_Rotation_IDX                                 = 92,
+    SBK_QtMultimediaQtVideo_IDX                              = 91,
+    SBK_QtMultimedia_IDX_COUNT                               = 93,
 };
 
 // This variable stores all Python types exported by this module.
@@ -310,9 +318,6 @@ namespace Shiboken
 // PyType functions, to get the PyObjectType for a type T
 template<> inline PyTypeObject *SbkType< ::QAbstractVideoBuffer >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAbstractVideoBuffer::MapData >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]); }
-template<> inline PyTypeObject *SbkType< ::QAudio::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudio_Error_IDX]); }
-template<> inline PyTypeObject *SbkType< ::QAudio::State >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudio_State_IDX]); }
-template<> inline PyTypeObject *SbkType< ::QAudio::VolumeScale >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudio_VolumeScale_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudioBuffer >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudioBufferInput >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBufferInput_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAudioBufferOutput >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBufferOutput_IDX]); }
@@ -394,6 +399,9 @@ template<> inline PyTypeObject *SbkType< ::QVideoSink >() { return Shiboken::Mod
 template<> inline PyTypeObject *SbkType< ::QWaveDecoder >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QWaveDecoder_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWindowCapture::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QWindowCapture_Error_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWindowCapture >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QWindowCapture_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QtAudio::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtAudio_Error_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QtAudio::State >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtAudio_State_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QtAudio::VolumeScale >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtAudio_VolumeScale_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QtVideo::Rotation >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtVideo_Rotation_IDX]); }
 
 } // namespace Shiboken
